@@ -1045,6 +1045,9 @@ class ServiceStub(ABC):
         if len(common_args) > 0:
             session.common_args = common_args
         
+        if session.common_args is None:
+            session.common_args = {}
+        
         self.suffix_url = "?" + urlencode(session.common_args)
         
         if target:
@@ -1073,17 +1076,20 @@ class ServiceStub(ABC):
         )
         # TODO 优化URL获取通过r.request.url,但也不一定是对的
         logger.info(f'[请求cookies]:{r.request.headers._store.get("cookie")}')
-        logger.info(f'[请求headers]:{r.request.headers.get("x1-bilispy-color")}')
+        logger.info(f'[请求color]:{r.request.headers.get("x1-bilispy-color")}')
         
         try:
             r_data = r.json()
         except Exception:
             r_data = r.text
         
-        logger.info(f'[响应结果]:{r_data}')
-        logger.info(f'[响应http_code]:{r.status_code}')
-        logger.info(f'[响应耗时]:{r.elapsed.total_seconds():0.2f}秒')
-        logger.info(f'[X-Trace-Id]:{r.headers.get("X-Trace-Id")}')
+        response_log = f'\n[响应结果]:{r_data}\n[响应http_code]:{r.status_code}\n' \
+                       f'[响应耗时]:{r.elapsed.total_seconds():0.2f}秒\n[响应X-Trace-Id]:{r.headers.get("X-Trace-Id")}\n'
+        logger.info(response_log)
+        # logger.info(f'[响应结果]:{r_data}')
+        # logger.info(f'[响应http_code]:{r.status_code}')
+        # logger.info(f'[响应耗时]:{r.elapsed.total_seconds():0.2f}秒')
+        # logger.info(f'[X-Trace-Id]:{r.headers.get("X-Trace-Id")}')
         # logger.info(f'[响应cookies]:{r.cookies}')
         response.__dict__.update(r.__dict__)
         
