@@ -24,7 +24,7 @@ from google.protobuf.descriptor_pb2 import (
     FieldDescriptorProto,
 )
 
-from betterproto.casing import safe_snake_case, sanitize_name
+from betterproto.casing import safe_snake_case
 
 WRAPPER_TYPES = {
     "google.protobuf.DoubleValue": "float",
@@ -48,16 +48,16 @@ def get_ref_type(package: str, imports: set, type_name: str) -> str:
     # because by convention packages are lowercase and message/enum types are
     # pascal-cased. May require refactoring in the future.
     type_name = type_name.lstrip(".")
-    
+
     if type_name in WRAPPER_TYPES:
         return f"Optional[{WRAPPER_TYPES[type_name]}]"
-    
+
     if type_name == "google.protobuf.Duration":
         return "timedelta"
-    
+
     if type_name == "google.protobuf.Timestamp":
         return "datetime"
-    
+
     if type_name.startswith(package):
         parts = type_name.lstrip(package).lstrip(".").split(".")
         if len(parts) == 1 or (len(parts) > 1 and parts[0][0] == parts[0][0].upper()):
@@ -65,7 +65,7 @@ def get_ref_type(package: str, imports: set, type_name: str) -> str:
             # foo.bar_thing => FooBarThing
             cased = [stringcase.pascalcase(part) for part in parts]
             type_name = f'"{"".join(cased)}"'
-    
+
     if "." in type_name:
         # This is imported from another package. No need
         # to use a forward ref and we need to add the import.
@@ -73,7 +73,7 @@ def get_ref_type(package: str, imports: set, type_name: str) -> str:
         parts[-1] = stringcase.pascalcase(parts[-1])
         imports.add(f"from .{'.'.join(parts[:-2])} import {parts[-2]}")
         type_name = f"{parts[-2]}.{parts[-1]}"
-    
+
     return type_name
 
 
@@ -112,7 +112,7 @@ def get_py_zero(type_num: int) -> str:
         zero = "None"
     elif type_num == 12:
         zero = 'b""'
-    
+
     return zero
 
 
@@ -122,16 +122,16 @@ def traverse(proto_file):
             # Adjust the name since we flatten the heirarchy.
             item.name = next_prefix = prefix + item.name
             yield item, path + [i]
-            
+
             if isinstance(item, DescriptorProto):
                 for enum in item.enum_type:
                     enum.name = next_prefix + enum.name
                     yield enum, path + [i, 4]
-                
+
                 if item.nested_type:
                     for n, p in _traverse(path + [i, 3], item.nested_type, next_prefix):
                         yield n, p
-    
+
     return itertools.chain(
         _traverse([5], proto_file.enum_type), _traverse([4], proto_file.message_type)
     )
@@ -145,7 +145,7 @@ def get_comment(proto_file, path: List[int], indent: int = 4) -> str:
             lines = textwrap.wrap(
                 sci.leading_comments.strip().replace("\n", ""), width=79 - indent
             )
-            
+
             if path[-2] == 2 and path[-4] != 6:
                 # This is a field
                 return f"{pad}# " + f"\n{pad}# ".join(lines)
@@ -157,7 +157,7 @@ def get_comment(proto_file, path: List[int], indent: int = 4) -> str:
                 else:
                     joined = f"\n{pad}".join(lines)
                     return f'{pad}"""\n{pad}{joined}\n{pad}"""'
-    
+
     return ""
 
 
@@ -168,23 +168,23 @@ def generate_code(request, response):
         loader=jinja2.FileSystemLoader("%s/templates/" % os.path.dirname(__file__)),
     )
     template = env.get_template("template.py")
-    
+
     output_map = {}
     for proto_file in request.proto_file:
-        out = proto_file.package
+        out = proto_file.name
         if out == "google.protobuf":
             continue
-        
+
         if not out:
             out = os.path.splitext(proto_file.name)[0].replace(os.path.sep, ".")
-        
+
         if out not in output_map:
             output_map[out] = {"package": proto_file.package, "files": []}
         output_map[out]["files"].append(proto_file)
-    
+
     # TODO: Figure out how to handle gRPC request/response messages and add
     # processing below for Service.
-    
+
     for filename, options in output_map.items():
         package = options["package"]
         # print(package, filename, file=sys.stderr)
@@ -198,25 +198,23 @@ def generate_code(request, response):
             "enums": [],
             "services": [],
         }
-        
-        type_mapping = {}
-        
+
         for proto_file in options["files"]:
             # print(proto_file.message_type, file=sys.stderr)
             # print(proto_file.service, file=sys.stderr)
             # print(proto_file.source_code_info, file=sys.stderr)
-            
+
             for item, path in traverse(proto_file):
                 # print(item, file=sys.stderr)
                 # print(path, file=sys.stderr)
                 data = {"name": item.name, "py_name": stringcase.pascalcase(item.name)}
-                
+
                 if isinstance(item, DescriptorProto):
                     # print(item, file=sys.stderr)
                     if item.options.map_entry:
                         # Skip generated map entry messages since we just use dicts
                         continue
-                    
+
                     data.update(
                         {
                             "type": "Message",
@@ -224,30 +222,30 @@ def generate_code(request, response):
                             "properties": [],
                         }
                     )
-                    
+
                     for i, f in enumerate(item.field):
                         t = py_type(package, output["imports"], item, f)
                         zero = get_py_zero(f.type)
-                        
+
                         repeated = False
                         packed = False
-                        
+
                         field_type = f.Type.Name(f.type).lower()[5:]
-                        
+
                         field_wraps = ""
                         if f.type_name.startswith(
                                 ".google.protobuf"
                         ) and f.type_name.endswith("Value"):
                             w = f.type_name.split(".").pop()[:-5].upper()
                             field_wraps = f"betterproto.TYPE_{w}"
-                        
+
                         map_types = None
                         if f.type == 11:
                             # This might be a map...
                             message_type = f.type_name.split(".").pop().lower()
                             # message_type = py_type(package)
                             map_entry = f"{f.name.replace('_', '').lower()}entry"
-                            
+
                             if message_type == map_entry:
                                 for nested in item.nested_type:
                                     if (
@@ -275,29 +273,29 @@ def generate_code(request, response):
                                                 f.Type.Name(nested.field[1].type),
                                             )
                                             output["typing_imports"].add("Dict")
-                        
+
                         if f.label == 3 and field_type != "map":
                             # Repeated field
                             repeated = True
                             t = f"List[{t}]"
                             zero = "[]"
                             output["typing_imports"].add("List")
-                            
+
                             if f.type in [1, 2, 3, 4, 5, 6, 7, 8, 13, 15, 16, 17, 18]:
                                 packed = True
-                        
+
                         one_of = ""
                         if f.HasField("oneof_index"):
                             one_of = item.oneof_decl[f.oneof_index].name
-                        
+
                         if "Optional[" in t:
                             output["typing_imports"].add("Optional")
-                        
+
                         if "timedelta" in t:
                             output["datetime_imports"].add("timedelta")
                         elif "datetime" in t:
                             output["datetime_imports"].add("datetime")
-                        
+
                         data["properties"].append(
                             {
                                 "name": f.name,
@@ -316,7 +314,7 @@ def generate_code(request, response):
                             }
                         )
                         # print(f, file=sys.stderr)
-                    
+
                     output["messages"].append(data)
                 elif isinstance(item, EnumDescriptorProto):
                     # print(item.name, path, file=sys.stderr)
@@ -334,23 +332,23 @@ def generate_code(request, response):
                             ],
                         }
                     )
-                    
+
                     output["enums"].append(data)
-            
+
             for i, service in enumerate(proto_file.service):
                 # print(service, file=sys.stderr)
-                
+
                 data = {
                     "name": service.name,
                     "py_name": stringcase.pascalcase(service.name),
                     "comment": get_comment(proto_file, [6, i]),
                     "methods": [],
                 }
-                
+
                 for j, method in enumerate(service.method):
                     if method.client_streaming:
                         raise NotImplementedError("Client streaming not yet supported")
-                    
+
                     input_message = None
                     input_type = get_ref_type(
                         package, output["imports"], method.input_type
@@ -362,11 +360,11 @@ def generate_code(request, response):
                                 if field["zero"] == "None":
                                     output["typing_imports"].add("Optional")
                             break
-                    
+
                     data["methods"].append(
                         {
                             "name": method.name,
-                            "py_name": sanitize_name(stringcase.snakecase(method.name)),
+                            "py_name": safe_snake_case(method.name),
                             "comment": get_comment(proto_file, [6, i, 2, j], indent=8),
                             "route": f"/{package}.{service.name}/{method.name}",
                             "input": get_ref_type(
@@ -380,27 +378,27 @@ def generate_code(request, response):
                             "server_streaming": method.server_streaming,
                         }
                     )
-                    
+
                     if method.server_streaming:
                         output["typing_imports"].add("AsyncGenerator")
-                
+
                 output["services"].append(data)
-        
+
         output["imports"] = sorted(output["imports"])
         output["datetime_imports"] = sorted(output["datetime_imports"])
         output["typing_imports"] = sorted(output["typing_imports"])
-        
+
         # Fill response
         f = response.file.add()
         # print(filename, file=sys.stderr)
-        f.name = filename.replace(".", os.path.sep) + ".py"
-        
+        f.name = package.replace(".", os.path.sep) + "/" + os.path.splitext(filename)[0].split("/", 4)[-1] + ".py"
+
         # Render and then format the output file.
         f.content = black.format_str(
             template.render(description=output),
             mode=black.FileMode(target_versions=set([black.TargetVersion.PY37])),
         )
-    
+
     inits = set([""])
     for f in response.file:
         # Ensure output paths exist
@@ -412,18 +410,18 @@ def generate_code(request, response):
             for part in dirnames.split(os.path.sep):
                 base = os.path.join(base, part)
                 inits.add(base)
-    
+
     for base in inits:
         name = os.path.join(base, "__init__.py")
-        
+
         if os.path.exists(name):
             # Never overwrite inits as they may have custom stuff in them.
             continue
-        
+
         init = response.file.add()
         init.name = name
         init.content = b""
-    
+
     filenames = sorted([f.name for f in response.file])
     for fname in filenames:
         print(f"Writing {fname}", file=sys.stderr)
@@ -433,20 +431,20 @@ def main():
     """The plugin's main entry point."""
     # Read request message from stdin
     data = sys.stdin.buffer.read()
-    
+
     # Parse request
     request = plugin.CodeGeneratorRequest()
     request.ParseFromString(data)
-    
+
     # Create response
     response = plugin.CodeGeneratorResponse()
-    
+
     # Generate code
     generate_code(request, response)
-    
+
     # Serialise response message
     output = response.SerializeToString()
-    
+
     # Write to stdout
     sys.stdout.buffer.write(output)
 
